==> s3-1.19.0-sources.jar: software/amazon/awscdk/services/s3/IBucketNotificationDestination.java <==
package software.amazon.awscdk.services.s3;

/**
 * Implemented by constructs that can be used as bucket notification destinations.
 */
@javax.annotation.Generated(value = "jsii-pacmak/0.20.11 (build d4fd44f)", date = "2019-12-17T13:05:38.825Z")
@software.amazon.jsii.Jsii(module = software.amazon.awscdk.services.s3.$Module.class, fqn = "@aws-cdk/aws-s3.IBucketNotificationDestination")
@software.amazon.jsii.Jsii.Proxy(IBucketNotificationDestination.Jsii$Proxy.class)
@software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
public interface IBucketNotificationDestination extends software.amazon.jsii.JsiiSerializable {

    /**
     * Registers this resource to receive notifications for the specified bucket.
     * 
     * <p>This method will only be called once for each destination/bucket
     * pair and the result will be cached, so there is no need to implement
     * idempotency in each destination.</p>
     * 
     * @param scope This parameter is required.
     * @param bucket The bucket object to bind to. This parameter is required.
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    software.amazon.awscdk.services.s3.BucketNotificationDestinationConfig bind(final software.amazon.awscdk.core.Construct scope, final software.amazon.awscdk.services.s3.IBucket bucket);

    /**
     * A proxy class which represents a concrete javascript instance of this type.
     */
    final static class Jsii$Proxy extends software.amazon.jsii.JsiiObject implements software.amazon.awscdk.services.s3.IBucketNotificationDestination {
        protected Jsii$Proxy(final software.amazon.jsii.JsiiObjectRef objRef) {
            super(objRef);
        }

        /**
         * Registers this resource to receive notifications for the specified bucket.
         * 
         * <p>This method will only be called once for each destination/bucket
         * pair and the result will be cached, so there is no need to implement
         * idempotency in each destination.</p>
         * 
         * @param scope This parameter is required.
         * @param bucket The bucket object to bind to. This parameter is required.
         */
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
        @Override
        public software.amazon.awscdk.services.s3.BucketNotificationDestinationConfig bind(final software.amazon.awscdk.core.Construct scope, final software.amazon.awscdk.services.s3.IBucket bucket) {
            return this.jsiiCall("bind", software.amazon.awscdk.services.s3.BucketNotificationDestinationConfig.class, new Object[] { java.util.Objects.requireNonNull(scope, "scope is required"), java.util.Objects.requireNonNull(bucket, "bucket is required") });
        }
    }
}

==> s3-1.20.0-sources.jar: software/amazon/awscdk/services/s3/IBucketNotificationDestination.java <==
package software.amazon.awscdk.services.s3;

/**
 * Implemented by constructs that can be used as bucket notification destinations.
 */
@javax.annotation.Generated(value = "jsii-pacmak/0.21.1 (build 9ff44cb)", date = "2020-01-07T23:10:48.578Z")
@software.amazon.jsii.Jsii(module = software.amazon.awscdk.services.s3.$Module.class, fqn = "@aws-cdk/aws-s3.IBucketNotificationDestination")
@software.amazon.jsii.Jsii.Proxy(IBucketNotificationDestination.Jsii$Proxy.class)
@software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
public interface IBucketNotificationDestination extends software.amazon.jsii.JsiiSerializable {

    /**
     * Registers this resource to receive notifications for the specified bucket.
     * <p>
     * This method will only be called once for each destination/bucket
     * pair and the result will be cached, so there is no need to implement
     * idempotency in each destination.
     * <p>
     * @param scope This parameter is required.
     * @param bucket The bucket object to bind to. This parameter is required.
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    software.amazon.awscdk.services.s3.BucketNotificationDestinationConfig bind(final software.amazon.awscdk.core.Construct scope, final software.amazon.awscdk.services.s3.IBucket bucket);

    /**
     * A proxy class which represents a concrete javascript instance of this type.
     */
    final static class Jsii$Proxy extends software.amazon.jsii.JsiiObject implements software.amazon.awscdk.services.s3.IBucketNotificationDestination {
        protected Jsii$Proxy(final software.amazon.jsii.JsiiObjectRef objRef) {
            super(objRef);
        }

        /**
         * Registers this resource to receive notifications for the specified bucket.
         * <p>
         * This method will only be called once for each destination/bucket
         * pair and the result will be cached, so there is no need to implement
         * idempotency in each destination.
         * <p>
         * @param scope This parameter is required.
         * @param bucket The bucket object to bind to. This parameter is required.
         */
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
        @Override
        public software.amazon.awscdk.services.s3.BucketNotificationDestinationConfig bind(final software.amazon.awscdk.core.Construct scope, final software.amazon.awscdk.services.s3.IBucket bucket) {
            return this.jsiiCall("bind", software.amazon.awscdk.services.s3.BucketNotificationDestinationConfig.class, new Object[] { java.util.Objects.requireNonNull(scope, "scope is required"), java.util.Objects.requireNonNull(bucket, "bucket is required") });
        }
    }
}
